@@ -4,6 +4,7 @@
 
 import pycurl
 import unittest
+import nose.tools
 import select
 
 from . import appmanager
@@ -366,3 +367,13 @@ class MultiTest(unittest.TestCase):
         m = pycurl.CurlMulti()
         m.close()
         m.close()
+    
+    # positional arguments are rejected
+    @nose.tools.raises(TypeError)
+    def test_positional_arguments(self):
+        pycurl.CurlMulti(1)
+    
+    # keyword arguments are rejected
+    @nose.tools.raises(TypeError)
+    def test_keyword_arguments(self):
+        pycurl.CurlMulti(a=1)
