@@ -1,5 +1,5 @@
 #! /usr/bin/env python
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 # vi:ts=4:et
 
 import pycurl
@@ -39,14 +39,13 @@ class MultiSocketTest(unittest.TestCase):
 
         # init
         m = pycurl.CurlMulti()
-        m.setopt(pycurl.M_PIPELINING, 1)
         m.setopt(pycurl.M_TIMERFUNCTION, timer)
         m.handles = []
         for url in urls:
             c = pycurl.Curl()
             # save info in standard Python attributes
             c.url = url
-            c.body = util.StringIO()
+            c.body = util.BytesIO()
             c.http_code = -1
             m.handles.append(c)
             # pycurl API calls
@@ -71,7 +70,7 @@ class MultiSocketTest(unittest.TestCase):
 
         # print result
         for c in m.handles:
-            self.assertEqual('success', c.body.getvalue())
+            self.assertEqual('success', c.body.getvalue().decode())
             self.assertEqual(200, c.http_code)
         
         assert len(timers) > 0
