@@ -4,11 +4,6 @@
 
 import pycurl
 import unittest
-import sys
-try:
-    import urllib.parse as urllib_parse
-except ImportError:
-    import urllib as urllib_parse
 
 from . import appmanager
 from . import util
@@ -18,22 +13,23 @@ setup_module, teardown_module = appmanager.setup(('app', 8380))
 class ResetTest(unittest.TestCase):
     def test_reset(self):
         c = pycurl.Curl()
-        c.setopt(pycurl.URL, 'http://localhost:8380/success')
-        c.reset()
-        try:
-            c.perform()
-            self.fail('Perform worked when it should not have')
-        except pycurl.error:
-            exc = sys.exc_info()[1]
-            code = exc.args[0]
-            self.assertEqual(pycurl.E_URL_MALFORMAT, code)
-        
-        # check that Curl object is usable
-        c.setopt(pycurl.URL, 'http://localhost:8380/success')
+        c.setopt(pycurl.USERAGENT, 'Phony/42')
+        c.setopt(pycurl.URL, 'http://localhost:8380/header?h=user-agent')
         sio = util.BytesIO()
         c.setopt(pycurl.WRITEFUNCTION, sio.write)
         c.perform()
-        self.assertEqual('success', sio.getvalue().decode())
+        user_agent = sio.getvalue().decode()
+        assert user_agent == 'Phony/42'
+        
+        c.reset()
+        c.setopt(pycurl.URL, 'http://localhost:8380/header?h=user-agent')
+        sio = util.BytesIO()
+        c.setopt(pycurl.WRITEFUNCTION, sio.write)
+        c.perform()
+        user_agent = sio.getvalue().decode()
+        # we also check that the request succeeded after curl
+        # object has been reset
+        assert user_agent.startswith('PycURL')
     
     # XXX this test was broken when it was test_reset.py
     def skip_reset_with_multi(self):
